@@ -64,8 +64,11 @@ class Dns:
             self.port_mapper.remove(service.port)
 
     def full_name(self):
+        return 'device.{}'.format(self.short_name())
+
+    def short_name(self):
         domain_config = self.domain_config.load()
-        return 'device.{}.{}'.format(domain_config.user_domain, self.main_domain_name)
+        return '{}.{}'.format(domain_config.user_domain, self.main_domain_name)
 
     def service_info(self, name):
         service = self.get_service(name)
