@@ -55,6 +55,9 @@ class Insider:
     def full_name(self):
         return self.dns.full_name()
 
+    def short_name(self):
+        return self.dns.short_name()
+
     def cron_on(self):
         return self.cron.on()
 
